pub struct Optimizer { /* private fields */ }Expand description
Main optimizer that applies optimization passes to a graph
Implementations
Sourceimpl Optimizer
impl Optimizer
Sourcepub fn new(level: OptimizationLevel) -> Self
pub fn new(level: OptimizationLevel) -> Self
Create a new optimizer with the specified optimization level
Sourcepub fn optimize(&self, graph: &mut ModelGraph) -> Result<OptimizationStats>
pub fn optimize(&self, graph: &mut ModelGraph) -> Result<OptimizationStats>
Optimize a model graph
Sourcepub fn pass_count(&self) -> usize
pub fn pass_count(&self) -> usize
Get the number of registered passes
Sourcepub fn level(&self) -> OptimizationLevel
pub fn level(&self) -> OptimizationLevel
Get the optimization level